@@ -50,12 +50,6 @@ struct _GncRecurrence
     Recurrence recurrence;
 };
 
-typedef struct
-{
-    GtkBoxClass parent_class;
-    void (*changed) (GncRecurrence *gr);
-} GncRecurrenceClass;
-
 typedef enum
 {
     GNCRECURRENCE_CHANGED,
@@ -353,7 +347,7 @@ gnc_recurrence_class_init( GncRecurrenceClass *klass )
     g_signal_new ("changed",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_FIRST,
-		  G_STRUCT_OFFSET (GncRecurrenceClass, changed),
+		  0,
 		  NULL,
 		  NULL,
 		  g_cclosure_marshal_VOID__VOID,
@@ -374,202 +368,4 @@ gnc_recurrence_new()
     return GTK_WIDGET(gr);
 }
 
-
-/* TODO: Maybe this stuff should go into another file.
- *
- */
-struct _GncRecurrenceComp
-{
-    GtkScrolledWindow widget;
-
-    GtkWidget  *vbox;
-    GtkWidget  *hbox;
-    GtkWidget  *hbb;
-    gint num_rec;
-    GtkButton *buttRemove;
-    GtkButton *buttAdd;
-
-    GList *rlist;
-};
-
-
-typedef struct
-{
-    GtkScrolledWindowClass parent_class;
-    void (*changed) (GncRecurrenceComp *gr);
-} GncRecurrenceCompClass;
-
-
-typedef enum
-{
-    GNCRECURRENCECOMP_CHANGED,
-    GNCRC_LAST_SIGNAL
-} GNCRC_Signals;
-
-
-static void grc_changed(GtkWidget *w, gpointer data)
-{
-    g_signal_emit_by_name(data, "changed");
-}
-
-
-static void addRecurrence(GncRecurrenceComp *grc, GncRecurrence *gr)
-{
-
-    gtk_box_pack_start(GTK_BOX(grc->vbox), GTK_WIDGET(gr),
-                       FALSE, FALSE, 3);
-    g_signal_connect( G_OBJECT(gr), "changed",
-                      G_CALLBACK(grc_changed), grc );
-    grc->num_rec++;
-
-    gtk_widget_set_sensitive(GTK_WIDGET(grc->buttRemove), (grc->num_rec > 1));
-    g_signal_emit_by_name(G_OBJECT(grc), "changed");
-
-
-}
-
-
-static void removeRecurrence(GncRecurrenceComp *grc)
-{
-    GList *children, *last;
-
-    grc->num_rec--;
-
-    children = gtk_container_get_children(GTK_CONTAINER(grc->vbox));
-    last = g_list_last(children);
-    gtk_widget_destroy(GTK_WIDGET(last->data));
-    g_list_free(children);
-    g_signal_emit_by_name(G_OBJECT(grc), "changed");
-
-
-    gtk_widget_set_sensitive(GTK_WIDGET(grc->buttRemove), (grc->num_rec > 1));
-
-}
-
-
-static void addClicked(GtkButton *b, gpointer data)
-{
-    GncRecurrenceComp *grc = data;
-    GncRecurrence *gr;
-
-    gr = GNC_RECURRENCE(gnc_recurrence_new());
-    addRecurrence(grc, gr);
-}
-
-
-static void removeClicked(GtkButton *b, gpointer data)
-{
-    GncRecurrenceComp *grc = data;
-
-    if (grc->num_rec > 1)
-        removeRecurrence(grc);
-}
-
-G_DEFINE_TYPE (GncRecurrenceComp, gnc_recurrence_comp, GTK_TYPE_SCROLLED_WINDOW)
-
-void
-gnc_recurrence_comp_set_list(GncRecurrenceComp *grc, const GList *rlist)
-{
-    const GList *iter;
-
-    g_return_if_fail(grc);
-
-    while (grc->num_rec > 0)
-        removeRecurrence(grc);
-
-    for (iter = rlist; iter; iter = iter->next)
-    {
-        GncRecurrence *gr = GNC_RECURRENCE(gnc_recurrence_new());
-
-        gnc_recurrence_set(gr, (Recurrence *)iter->data);
-        addRecurrence(grc, gr);
-    }
-}
-
-
-GList *
-gnc_recurrence_comp_get_list(GncRecurrenceComp *grc)
-{
-    GList *rlist = NULL, *children;
-
-    children = gtk_container_get_children(GTK_CONTAINER(grc->vbox));
-    for (GList *n = children; n; n = n->next)
-    {
-        const Recurrence *r = gnc_recurrence_get (GNC_RECURRENCE (n->data));
-        rlist = g_list_prepend (rlist, (gpointer)r);
-    }
-    g_list_free(children);
-    return g_list_reverse (rlist);
-}
-
-
-static void
-gnc_recurrence_comp_init(GncRecurrenceComp *grc)
-{
-    GtkWidget *vb;
-
-    gtk_orientable_set_orientation (GTK_ORIENTABLE(grc), GTK_ORIENTATION_VERTICAL);
-
-    grc->hbb = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-    grc->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
-    gtk_box_set_homogeneous (GTK_BOX (grc->vbox), FALSE);
-    grc->rlist = NULL;
-
-    grc->buttAdd = GTK_BUTTON(gtk_button_new_with_mnemonic(_("_Add")));
-    g_signal_connect(G_OBJECT(grc->buttAdd), "clicked",
-                     G_CALLBACK(addClicked), grc);
-    grc->buttRemove = GTK_BUTTON(gtk_button_new_with_mnemonic(_("_Remove")));
-    g_signal_connect(G_OBJECT(grc->buttRemove), "clicked",
-                     G_CALLBACK(removeClicked), grc);
-
-    gtk_box_pack_start(GTK_BOX(grc->hbb), GTK_WIDGET(grc->buttAdd),
-                       FALSE, FALSE, 3);
-    gtk_box_pack_start(GTK_BOX(grc->hbb), GTK_WIDGET(grc->buttRemove),
-                       FALSE, FALSE, 3);
-
-    vb = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
-    gtk_box_set_homogeneous (GTK_BOX (vb), FALSE);
-    gtk_box_pack_start(GTK_BOX(vb), GTK_WIDGET(grc->hbb),
-                       FALSE, FALSE, 3);
-    gtk_box_pack_start(GTK_BOX(vb), GTK_WIDGET(grc->vbox),
-                       FALSE, FALSE, 3);
-
-    gtk_container_add (GTK_CONTAINER(grc), GTK_WIDGET(vb));
-
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(grc),
-                                   GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-
-    grc->num_rec = 0;
-    gtk_widget_show_all(GTK_WIDGET(grc));
-    addClicked(NULL, grc);
-}
-
-
-static void
-gnc_recurrence_comp_class_init( GncRecurrenceCompClass *klass )
-{
-    GObjectClass *object_class;
-
-    object_class = G_OBJECT_CLASS (klass);
-    g_signal_new ("changed",
-		  G_OBJECT_CLASS_TYPE (object_class),
-		  G_SIGNAL_RUN_FIRST,
-		  G_STRUCT_OFFSET (GncRecurrenceCompClass, changed),
-		  NULL,
-		  NULL,
-		  g_cclosure_marshal_VOID__VOID,
-		  G_TYPE_NONE,
-		  0);
-
-    //object_class->finalize = gnc_recurrence_finalize;
-}
-
-GtkWidget *
-gnc_recurrence_comp_new()
-{
-    GncRecurrenceComp *grc;
-    grc = g_object_new(gnc_recurrence_comp_get_type(), NULL);
-    return GTK_WIDGET(grc);
-}
-
 /* ========================= END OF FILE =========================== */
