@@ -280,27 +280,13 @@ void
 gnc_employee_name_changed_cb (GtkWidget *widget, gpointer data)
 {
     EmployeeWindow *ew = data;
-    char *title;
-
     if (!ew)
         return;
 
-    const char *header = (ew->dialog_type == EDIT_EMPLOYEE) ?
-        _("Edit Employee") : _("New Employee");
-
-    const char *name = gtk_entry_get_text (GTK_ENTRY (ew->name_entry));
-    if (!name || *name == '\0')
-        name = _("<No name>");
-
-    const char *id = gtk_entry_get_text (GTK_ENTRY (ew->id_entry));
-    if (id && *id)
-        title = g_strdup_printf ("%s - %s (%s)", header, name, id);
-    else
-        title = g_strdup_printf ("%s - %s", header, name);
-
-    gtk_window_set_title (GTK_WINDOW (ew->dialog), title);
-
-    g_free (title);
+    gnc_owner_window_set_title (GTK_WINDOW (ew->dialog),
+                                (ew->dialog_type == EDIT_EMPLOYEE) ?
+                                _("Edit Employee") : _("New Employee"),
+                                ew->name_entry, ew->id_entry);
 }
 
 void
