@@ -154,6 +154,7 @@ static void gnc_ui_to_order (OrderWindow *ow, GncOrder *order)
 
     gncOrderCommitEdit (order);
     gnc_resume_gui_refresh ();
+    g_free (text);
 }
 
 static gboolean
@@ -231,7 +232,7 @@ void
 gnc_order_window_help_cb (GtkWidget *widget, gpointer data)
 {
     OrderWindow *ow = data;
-    gnc_gnome_help (GTK_WINDOW(ow->dialog), HF_HELP, HL_USAGE_BILL);
+    gnc_gnome_help (GTK_WINDOW(ow->dialog), DF_MANUAL, DL_USAGE_BILL);
 }
 
 void
@@ -648,7 +649,6 @@ gnc_order_new_window (GtkWindow *parent, QofBook *bookp, OrderDialogType type,
     gnc_entry_ledger_set_parent (entry_ledger, ow->dialog);
 
     vbox = GTK_WIDGET(gtk_builder_get_object (builder, "ledger_vbox"));
-    // gtk_box_pack_start (GTK_BOX(vbox), toolbar, FALSE, FALSE, 2);
     gtk_box_pack_start (GTK_BOX(vbox), regWidget, TRUE, TRUE, 2);
 
     /* Setup signals */
