@@ -110,13 +110,9 @@ gnc_style_sheet_options_apply_cb (GncOptionsDialog * propertybox,
                                   gpointer user_data)
 {
     ss_info * ssi = (ss_info *)user_data;
-    GHashTable *reports = NULL;
     GList *results = NULL, *iter;
 
-    /* FIXME: shouldn't be global */
-    reports = gnc_reports_get_global ();
-    if (reports)
-        g_hash_table_foreach (reports, dirty_same_stylesheet, ssi->stylesheet);
+    gnc_reports_foreach (dirty_same_stylesheet, ssi->stylesheet);
 
     results = gnc_option_db_commit (ssi->odb);
     for (iter = results; iter; iter = iter->next)
