@@ -770,6 +770,8 @@ gnc_plugin_page_account_tree_destroy_widget (GncPluginPage *plugin_page)
 // Save account filter state information to account section
     gnc_tree_view_account_save_filter (GNC_TREE_VIEW_ACCOUNT(priv->tree_view), &priv->fd,
        gnc_state_get_current(), gnc_tree_view_get_state_section (GNC_TREE_VIEW(priv->tree_view)));
+    g_object_unref(G_OBJECT(priv->tree_view));
+    priv->tree_view = NULL;
 
     // Destroy the filter override hash table
     g_hash_table_destroy(priv->fd.filter_override);
@@ -780,10 +782,10 @@ gnc_plugin_page_account_tree_destroy_widget (GncPluginPage *plugin_page)
     // Remove the page focus idle function if present
     g_idle_remove_by_data (plugin_page);
 
-    if (priv->widget)
+    if (priv->tree_view)
     {
-        g_object_unref(G_OBJECT(priv->widget));
-        priv->widget = NULL;
+        gtk_widget_destroy(GTK_WIDGET(priv->tree_view));
+        priv->tree_view = NULL;
     }
 
     if (priv->component_id)
@@ -1314,6 +1316,7 @@ commodity_mismatch_dialog (const Account* account, GtkWindow* parent)
     response = gtk_dialog_run (GTK_DIALOG (error_dialog));
     gtk_widget_destroy (error_dialog);
     g_free (message);
+    g_free (account_name);
     return response;
 }
 
@@ -1529,6 +1532,7 @@ gnc_plugin_page_account_tree_cmd_delete_account (GSimpleAction *simple,
         g_list_free(list);
         return;
     }
+    g_list_free (list);
 
     window = gnc_plugin_page_get_window(GNC_PLUGIN_PAGE(page));
     acct_name = gnc_account_get_full_name(account);
@@ -1542,6 +1546,7 @@ gnc_plugin_page_account_tree_cmd_delete_account (GSimpleAction *simple,
         g_free(acct_name);
         return;
     }
+    g_free (acct_name);
 
     // If no transaction or children just delete it.
     if (xaccAccountGetSplits (account).empty() && gnc_account_n_children (account) == 0)
@@ -1694,11 +1699,22 @@ do_delete_account (Account* account, Account* saa, Account* sta, Account* ta)
                                        (AccountCb)xaccAccountMoveAllSplits,
                                        sta);
     }
+    else
+    {
+        gnc_account_foreach_descendant (account,
+                                        [](auto acc, [[maybe_unused]] auto data)
+                                        { xaccAccountDestroyAllTransactions(acc); },
+                                        nullptr);
+    }
     if (ta)
     {
         /* Move the splits of the account to be deleted. */
         xaccAccountMoveAllSplits (account, ta);
     }
+    else
+    {
+        xaccAccountDestroyAllTransactions (account);
+    }
     xaccAccountCommitEdit (account);
 
     /* Drop all references from the state file for
