@@ -102,7 +102,7 @@ typedef struct GncPluginPageReportPrivate
     /// The report-id
     int reportId;
     gint component_manager_id;
-
+    GSimpleActionGroup* action_group;
     /// The report which this Page is satisfying
     SCM cur_report;
     /// The Option DB for this report.
@@ -201,6 +201,18 @@ static GActionEntry report_actions[] =
     { "ReportStopAction", gnc_plugin_page_report_stop_cb, nullptr, nullptr, nullptr },
 };
 static guint num_report_actions = G_N_ELEMENTS(report_actions);
+static const gchar *initially_insensitive_actions[] =
+{
+    nullptr
+};
+
+static const gchar *disable_during_load_actions[] =
+{
+    "FilePrintAction",
+    "FilePrintPDFAction",
+    "ReportOptionsAction",
+    nullptr
+};
 
 /** The default menu items that need to be add to the menu */
 static const gchar *gnc_plugin_load_ui_items [] =
@@ -323,7 +335,7 @@ gnc_plugin_page_report_focus_widget (GncPluginPage *report_plugin_page)
             if (!priv->loaded) // so we only do the load once
                 gnc_plugin_page_report_load_uri (report_plugin_page);
 
-            if (GTK_IS_WIDGET(widget))
+            if (widget && GTK_IS_WIDGET(widget))
             {
                 if (!gtk_widget_is_focus (GTK_WIDGET(widget)))
                     gtk_widget_grab_focus (GTK_WIDGET(widget));
@@ -443,6 +455,8 @@ gnc_plugin_page_report_load_uri (GncPluginPage *page)
         g_object_remove_weak_pointer(G_OBJECT(page), (gpointer*)(&weak_page));
     }
 
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, TRUE);
     // this resets the window for the progressbar to nullptr
     gnc_window_set_progressbar_window( nullptr );
 }
@@ -660,7 +674,12 @@ gnc_plugin_page_report_load_cb (GncHtml * html, URLType type,
             && (strlen(location) > 3)
             && !strncmp("id=", location, 3))
     {
-        report_id = atoi(location + 3);
+        report_id = gnc_report_id_string_to_report_id (location + 3);
+        if (report_id < 0)
+        {
+            LEAVE ("id_string error %s", location);
+            return;
+        }
         DEBUG( "parsed id=%d", report_id );
     }
     else if (!g_strcmp0( type, URL_TYPE_OPTIONS)
@@ -794,6 +813,8 @@ gnc_plugin_page_report_option_change_cb(gpointer data)
     /* it's probably already dirty, but make sure */
     scm_call_2(dirty_report, priv->cur_report, SCM_BOOL_T);
 
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, FALSE);
     // prevent closing this page while loading...
     priv->reloading = TRUE;
 
@@ -811,6 +832,8 @@ gnc_plugin_page_report_option_change_cb(gpointer data)
     // this resets the window for the progressbar to nullptr
     gnc_window_set_progressbar_window( nullptr );
 
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, TRUE);
     priv->reloading = FALSE;
 }
 
@@ -1175,14 +1198,11 @@ gnc_plugin_page_report_destroy(GncPluginPageReportPrivate * priv)
         scm_gc_unprotect_object(priv->edited_reports);
 }
 
-static const gchar *initially_insensitive_actions[] =
-{
-    nullptr
-};
-
 static void
 gnc_plugin_page_report_init ( GncPluginPageReport *plugin_page )
 {
+    GncPluginPageReportPrivate *priv = GNC_PLUGIN_PAGE_REPORT_GET_PRIVATE(plugin_page);
+    priv->action_group = NULL;
 }
 
 static GObject*
@@ -1277,7 +1297,6 @@ static void
 gnc_plugin_page_report_constr_init (GncPluginPageReport *plugin_page, gint reportId)
 {
     GncPluginPageReportPrivate *priv;
-    GSimpleActionGroup *simple_action_group;
     GncPluginPage *parent;
     gboolean use_new;
     gchar *name;
@@ -1304,14 +1323,16 @@ gnc_plugin_page_report_constr_init (GncPluginPageReport *plugin_page, gint repor
     gnc_plugin_page_add_book (parent, gnc_get_current_book());
 
     /* Create menu and toolbar information */
-    simple_action_group = gnc_plugin_page_create_action_group (parent, "GncPluginPageReportActions");
-    g_action_map_add_action_entries (G_ACTION_MAP(simple_action_group),
+    priv->action_group = gnc_plugin_page_create_action_group (parent, "GncPluginPageReportActions");
+    g_action_map_add_action_entries (G_ACTION_MAP(priv->action_group),
                                      report_actions,
                                      num_report_actions,
                                      plugin_page);
 
-    gnc_plugin_set_actions_enabled (G_ACTION_MAP(simple_action_group), initially_insensitive_actions,
+    gnc_plugin_set_actions_enabled (G_ACTION_MAP(priv->action_group), initially_insensitive_actions,
                                     FALSE);
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, FALSE);
 }
 
 GncPluginPage*
@@ -1456,7 +1477,9 @@ gnc_plugin_page_report_reload_cb (GSimpleAction *simple,
     scm_call_2(dirty_report, priv->cur_report, SCM_BOOL_T);
 
     /* now queue the fact that we need to reload this report */
-
+    // Disable some actions reported to crash while loading
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, FALSE);
     // prevent closing this page while loading...
     priv->reloading = TRUE;
     // this sets the window for the progressbar
@@ -1471,6 +1494,8 @@ gnc_plugin_page_report_reload_cb (GSimpleAction *simple,
 
     // this resets the window for the progressbar to nullptr
     gnc_window_set_progressbar_window( nullptr );
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, TRUE);
     priv->reloading = FALSE;
 }
 
@@ -1697,6 +1722,13 @@ gnc_plugin_page_report_save_cb (GSimpleAction *simple,
     check_func = scm_c_eval_string("gnc:is-custom-report-type");
     if (scm_is_true (scm_call_1 (check_func, priv->cur_report)))
     {
+        auto report_name_str{priv->cur_odb->lookup_string_option("General", "Report name")};
+        auto window{GTK_WINDOW(gnc_plugin_page_get_window (GNC_PLUGIN_PAGE(report)))};
+
+        if (!gnc_action_dialog (window, _("_Overwrite"), false, _("This will update and \
+overwrite the existing saved report named \"%s\"."), report_name_str.c_str()))
+            return;
+
         /* The current report is already based on a custom report.
          * Replace the existing one instead of adding a new one
          */
