@@ -37,42 +37,36 @@
 #include "gnc-engine.h"
 #include "window-report.h"
 
-static void gnc_plugin_report_system_class_init (GncPluginReportSystemClass *klass);
-static void gnc_plugin_report_system_init (GncPluginReportSystem *plugin);
 static void gnc_plugin_report_system_finalize (GObject *object);
 
 
 /* Command callbacks */
-static void gnc_plugin_report_system_cmd_edit_style_sheet (GtkAction *action,
-        GncMainWindowActionData *data);
+static void gnc_plugin_report_system_cmd_edit_style_sheet (GSimpleAction *simple, GVariant *parameter, gpointer user_data);
 
 
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-report-system-actions"
-#define PLUGIN_UI_FILENAME  "gnc-plugin-report-system-ui.xml"
+#define PLUGIN_UI_FILENAME  "gnc-plugin-report-system.ui"
 
-static GtkActionEntry gnc_plugin_actions [] =
+static GActionEntry gnc_plugin_actions [] =
 {
-    /* Menu Items */
-    {
-        "EditStyleSheetsAction", NULL, N_("St_yle Sheets"), NULL,
-        N_("Edit report style sheets"),
-        G_CALLBACK (gnc_plugin_report_system_cmd_edit_style_sheet)
-    },
+    { "EditStyleSheetsAction", gnc_plugin_report_system_cmd_edit_style_sheet, NULL, NULL, NULL },
 };
+/** The number of actions provided by this plugin. */
 static guint gnc_plugin_n_actions = G_N_ELEMENTS (gnc_plugin_actions);
 
-
-typedef struct GncPluginReportSystemPrivate
+/** The default menu items that need to be add to the menu */
+static const gchar *gnc_plugin_load_ui_items [] =
 {
-    gpointer dummy;
-} GncPluginReportSystemPrivate;
+    "EditPlaceholder4",
+    NULL,
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE(GncPluginReportSystem, gnc_plugin_report_system, GNC_TYPE_PLUGIN)
+struct _GncPluginReportSystem
+{
+    GncPlugin gnc_plugin;
+};
 
-#define GNC_PLUGIN_REPORT_SYSTEM_GET_PRIVATE(o)  \
-   (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_PLUGIN_REPORT_SYSTEM, GncPluginReportSystemPrivate))
-
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE(GncPluginReportSystem, gnc_plugin_report_system, GNC_TYPE_PLUGIN)
 
 /************************************************************
  *                   Object Implementation                  *
@@ -84,18 +78,17 @@ gnc_plugin_report_system_class_init (GncPluginReportSystemClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GncPluginClass *plugin_class = GNC_PLUGIN_CLASS (klass);
 
-    parent_class = g_type_class_peek_parent (klass);
-
     object_class->finalize = gnc_plugin_report_system_finalize;
 
     /* plugin info */
     plugin_class->plugin_name  = GNC_PLUGIN_REPORT_SYSTEM_NAME;
 
     /* widget addition/removal */
-    plugin_class->actions_name  	   = PLUGIN_ACTIONS_NAME;
-    plugin_class->actions       	   = gnc_plugin_actions;
-    plugin_class->n_actions     	   = gnc_plugin_n_actions;
-    plugin_class->ui_filename   	   = PLUGIN_UI_FILENAME;
+    plugin_class->actions_name    = PLUGIN_ACTIONS_NAME;
+    plugin_class->actions         = gnc_plugin_actions;
+    plugin_class->n_actions       = gnc_plugin_n_actions;
+    plugin_class->ui_filename     = PLUGIN_UI_FILENAME;
+    plugin_class->ui_updates      = gnc_plugin_load_ui_items;
 }
 
 static void
@@ -108,7 +101,7 @@ gnc_plugin_report_system_finalize (GObject *object)
 {
     g_return_if_fail (GNC_IS_PLUGIN_REPORT_SYSTEM (object));
 
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+    G_OBJECT_CLASS (gnc_plugin_report_system_parent_class)->finalize (object);
 }
 
 /************************************************************
@@ -116,10 +109,12 @@ gnc_plugin_report_system_finalize (GObject *object)
  ************************************************************/
 
 static void
-gnc_plugin_report_system_cmd_edit_style_sheet (GtkAction *action,
-        GncMainWindowActionData *data)
+gnc_plugin_report_system_cmd_edit_style_sheet (GSimpleAction *simple,
+                                               GVariant      *parameter,
+                                               gpointer       user_data)
 {
-    gnc_style_sheet_dialog_open(GTK_WINDOW (data->window));
+    GncMainWindowActionData *data = user_data;
+    gnc_style_sheet_dialog_open (GTK_WINDOW(data->window));
 }
 
 /************************************************************
@@ -133,6 +128,25 @@ gnc_report_system_file_stream_cb (const char *location, char ** data, int *len)
     return (*len > 0);
 }
 
+static char *
+html_sanitize (const char *str)
+{
+    g_return_val_if_fail (str, NULL);
+    GString *gs = g_string_sized_new (strlen (str));
+    for (const char *c = str; *c; c++)
+    {
+        if (*c == '&')
+            gs = g_string_append (gs, "&amp;");
+        else if (*c == '<')
+            gs = g_string_append (gs, "&lt;");
+        else if (*c == '>')
+            gs = g_string_append (gs, "&gt;");
+        else
+            gs = g_string_append_c (gs, *c);
+    }
+    return g_string_free (gs, FALSE);
+}
+
 static gboolean
 gnc_report_system_report_stream_cb (const char *location, char ** data, int *len)
 {
@@ -143,12 +157,14 @@ gnc_report_system_report_stream_cb (const char *location, char ** data, int *len
 
     if (!ok)
     {
+        char *sanitized = html_sanitize (captured_str);
         *data = g_strdup_printf ("<html><body><h3>%s</h3>"
                                  "<p>%s</p><pre>%s</pre></body></html>",
                                  _("Report error"),
                                  _("An error occurred while running the report."),
-                                 captured_str);
+                                 sanitized);
 
+        g_free (sanitized);
         g_free(captured_str);
 
         /* Make sure the progress bar is finished, which will also
