@@ -30,7 +30,11 @@
 #include <Split.h>
 #include <gnc-numeric.hpp>
 #include <gnc-datetime.hpp>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcpp"
 #include <gtest/gtest.h>
+#pragma GCC diagnostic pop
+
 extern "C"
 {
 #include <gnc-pricedb-p.h>
