@@ -27,6 +27,10 @@
 #include "Account.h"
 #include <gtk/gtk.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 
 /** STRUCTS *********************************************************/
 typedef struct _RecnWindow RecnWindow;
@@ -66,4 +70,8 @@ void gnc_ui_reconcile_window_raise (RecnWindow * recnData);
 
 GtkWindow *gnc_ui_reconcile_window_get_window (RecnWindow * recnData);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* WINDOW_RECONCILE_H */
