@@ -22,7 +22,6 @@
 
 #include <guid.hpp>
 
-extern "C" {
 #include <platform.h>
 #if PLATFORM(WINDOWS)
 #include <windows.h>
@@ -33,7 +32,15 @@ extern "C" {
 #include "gnc-ui-util.h" //get book
 #include "gnc-commodity.h"
 #include "gnc-pricedb.h"
-}
+
+#include <algorithm>
+#include <exception>
+#include <iostream>
+#include <memory>
+#include <optional>
+#include <string>
+#include <tuple>
+#include <vector>
 
 #include <boost/regex.hpp>
 #include <boost/regex/icu.hpp>
@@ -240,8 +247,8 @@ void GncPriceImport::encoding (const std::string& encoding)
 
 std::string GncPriceImport::encoding () { return m_settings.m_encoding; }
 
-void GncPriceImport::update_skipped_lines(boost::optional<uint32_t> start, boost::optional<uint32_t> end,
-        boost::optional<bool> alt, boost::optional<bool> errors)
+void GncPriceImport::update_skipped_lines(std::optional<uint32_t> start, std::optional<uint32_t> end,
+        std::optional<bool> alt, std::optional<bool> errors)
 {
     if (start)
         m_settings.m_skip_start_lines = *start;
@@ -504,7 +511,7 @@ std::string GncPriceImport::verify ()
 
     verify_column_selections (error_msg);
 
-    update_skipped_lines (boost::none, boost::none, boost::none, boost::none);
+    update_skipped_lines (std::nullopt, std::nullopt, std::nullopt, std::nullopt);
 
     auto have_line_errors = false;
     for (auto line : m_parsed_lines)
