@@ -31,38 +31,35 @@
 #include "gnc-plugin-manager.h"
 #include "gnc-component-manager.h"
 
-static void gnc_plugin_log_replay_class_init (GncPluginLogreplayClass *klass);
-static void gnc_plugin_log_replay_init (GncPluginLogreplay *plugin);
 static void gnc_plugin_log_replay_finalize (GObject *object);
 
 /* Command callbacks */
-static void gnc_plugin_log_replay_cmd_new_log_replay (GtkAction *action, GncMainWindowActionData *data);
+static void gnc_plugin_log_replay_cmd_new_log_replay (GSimpleAction *simple, GVariant *parameter, gpointer user_data);
 
 
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-log-replay-actions"
-#define PLUGIN_UI_FILENAME  "gnc-plugin-log-replay-ui.xml"
+#define PLUGIN_UI_FILENAME  "gnc-plugin-log-replay.ui"
 
-static GtkActionEntry gnc_plugin_actions [] =
+static GActionEntry gnc_plugin_actions [] =
 {
-    {
-        "LogReplayAction", "go-previous", N_("_Replay GnuCash .log file..."), NULL,
-        N_("Replay a GnuCash log file after a crash. This cannot be undone."),
-        G_CALLBACK (gnc_plugin_log_replay_cmd_new_log_replay)
-    },
+    { "LogReplayAction", gnc_plugin_log_replay_cmd_new_log_replay, NULL, NULL, NULL },
 };
-static guint gnc_plugin_n_actions = G_N_ELEMENTS (gnc_plugin_actions);
+/** The number of actions provided by this plugin. */
+static guint gnc_plugin_n_actions = G_N_ELEMENTS(gnc_plugin_actions);
 
-typedef struct GncPluginLogreplayPrivate
+/** The default menu items that need to be add to the menu */
+static const gchar *gnc_plugin_load_ui_items [] =
 {
-    gpointer dummy;
-} GncPluginLogreplayPrivate;
+    "FilePlaceholder1",
+    NULL,
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE(GncPluginLogreplay, gnc_plugin_log_replay, GNC_TYPE_PLUGIN)
+struct _GncPluginLogReplay
+{
+    GncPlugin gnc_plugin;
+};
 
-#define GNC_PLUGIN_LOG_REPLAY_GET_PRIVATE(o)  \
-   ((GncPluginLogreplayPrivate*)gnc_plugin_log_replay_get_instance_private((GncPluginLogReplay*)o))
-
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE(GncPluginLogReplay, gnc_plugin_log_replay, GNC_TYPE_PLUGIN)
 
 GncPlugin *
 gnc_plugin_log_replay_new (void)
@@ -71,27 +68,26 @@ gnc_plugin_log_replay_new (void)
 }
 
 static void
-gnc_plugin_log_replay_class_init (GncPluginLogreplayClass *klass)
+gnc_plugin_log_replay_class_init (GncPluginLogReplayClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GncPluginClass *plugin_class = GNC_PLUGIN_CLASS (klass);
 
-    parent_class = g_type_class_peek_parent (klass);
-
     object_class->finalize = gnc_plugin_log_replay_finalize;
 
     /* plugin info */
     plugin_class->plugin_name  = GNC_PLUGIN_LOG_REPLAY_NAME;
 
     /* widget addition/removal */
-    plugin_class->actions_name = PLUGIN_ACTIONS_NAME;
-    plugin_class->actions      = gnc_plugin_actions;
-    plugin_class->n_actions    = gnc_plugin_n_actions;
-    plugin_class->ui_filename  = PLUGIN_UI_FILENAME;
+    plugin_class->actions_name    = PLUGIN_ACTIONS_NAME;
+    plugin_class->actions         = gnc_plugin_actions;
+    plugin_class->n_actions       = gnc_plugin_n_actions;
+    plugin_class->ui_filename     = PLUGIN_UI_FILENAME;
+    plugin_class->ui_updates      = gnc_plugin_load_ui_items;
 }
 
 static void
-gnc_plugin_log_replay_init (GncPluginLogreplay *plugin)
+gnc_plugin_log_replay_init (GncPluginLogReplay *plugin)
 {
 }
 
@@ -100,7 +96,7 @@ gnc_plugin_log_replay_finalize (GObject *object)
 {
     g_return_if_fail (GNC_IS_PLUGIN_LOG_REPLAY (object));
 
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+    G_OBJECT_CLASS (gnc_plugin_log_replay_parent_class)->finalize (object);
 }
 
 /************************************************************
@@ -112,9 +108,11 @@ gnc_plugin_log_replay_finalize (GObject *object)
  ************************************************************/
 
 static void
-gnc_plugin_log_replay_cmd_new_log_replay (GtkAction *action,
-        GncMainWindowActionData *data)
+gnc_plugin_log_replay_cmd_new_log_replay (GSimpleAction *simple,
+                                          GVariant      *parameter,
+                                          gpointer       user_data)
 {
+    GncMainWindowActionData *data = user_data;
     gnc_suspend_gui_refresh();
     gnc_file_log_replay (GTK_WINDOW (data->window));
     gnc_resume_gui_refresh();
