@@ -32,37 +32,34 @@
 #include "gnc-plugin-manager.h"
 #include "gnc-plugin-qif-import.h"
 
-static void gnc_plugin_qif_import_class_init (GncPluginQifImportClass *klass);
-static void gnc_plugin_qif_import_init (GncPluginQifImport *plugin);
 static void gnc_plugin_qif_import_finalize (GObject *object);
 
 /* Command callbacks */
-static void gnc_plugin_qif_import_cmd_new_qif_import (GtkAction *action, GncMainWindowActionData *data);
+static void gnc_plugin_qif_import_cmd_new_qif_import (GSimpleAction *simple, GVariant *parameter, gpointer user_data);
 
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-qif-import-actions"
-#define PLUGIN_UI_FILENAME  "gnc-plugin-qif-import-ui.xml"
+#define PLUGIN_UI_FILENAME  "gnc-plugin-qif-import.ui"
 
-static GtkActionEntry gnc_plugin_actions [] =
+static GActionEntry gnc_plugin_actions [] =
 {
-    {
-        "QIFImportAction", "go-previous", N_("Import _QIF..."), NULL,
-        N_("Import a Quicken QIF file"),
-        G_CALLBACK (gnc_plugin_qif_import_cmd_new_qif_import)
-    },
+    { "QIFImportAction", gnc_plugin_qif_import_cmd_new_qif_import, NULL, NULL, NULL },
 };
-static guint gnc_plugin_n_actions = G_N_ELEMENTS (gnc_plugin_actions);
+/** The number of actions provided by this plugin. */
+static guint gnc_plugin_n_actions = G_N_ELEMENTS(gnc_plugin_actions);
 
-typedef struct GncPluginQifImportPrivate
+/** The default menu items that need to be add to the menu */
+static const gchar *gnc_plugin_load_ui_items [] =
 {
-    gpointer dummy;
-} GncPluginQifImportPrivate;
+    "FilePlaceholder1",
+    NULL,
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE(GncPluginQifImport, gnc_plugin_qif_import, GNC_TYPE_PLUGIN);
+struct _GncPluginQifImport
+{
+    GncPlugin gnc_plugin;
+};
 
-#define GNC_PLUGIN_QIF_IMPORT_GET_PRIVATE(o)  \
-   ((GncPluginQifImportPrivate*)gnc_plugin_qif_import_get_instance_private((GncPluginQifImport*)o))
-
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE(GncPluginQifImport, gnc_plugin_qif_import, GNC_TYPE_PLUGIN)
 
 GncPlugin *
 gnc_plugin_qif_import_new (void)
@@ -76,18 +73,17 @@ gnc_plugin_qif_import_class_init (GncPluginQifImportClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GncPluginClass *plugin_class = GNC_PLUGIN_CLASS (klass);
 
-    parent_class = g_type_class_peek_parent (klass);
-
     object_class->finalize = gnc_plugin_qif_import_finalize;
 
     /* plugin info */
     plugin_class->plugin_name  = GNC_PLUGIN_QIF_IMPORT_NAME;
 
     /* widget addition/removal */
-    plugin_class->actions_name = PLUGIN_ACTIONS_NAME;
-    plugin_class->actions      = gnc_plugin_actions;
-    plugin_class->n_actions    = gnc_plugin_n_actions;
-    plugin_class->ui_filename  = PLUGIN_UI_FILENAME;
+    plugin_class->actions_name    = PLUGIN_ACTIONS_NAME;
+    plugin_class->actions         = gnc_plugin_actions;
+    plugin_class->n_actions       = gnc_plugin_n_actions;
+    plugin_class->ui_filename     = PLUGIN_UI_FILENAME;
+    plugin_class->ui_updates      = gnc_plugin_load_ui_items;
 }
 
 static void
@@ -100,7 +96,7 @@ gnc_plugin_qif_import_finalize (GObject *object)
 {
     g_return_if_fail (GNC_IS_PLUGIN_QIF_IMPORT (object));
 
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+    G_OBJECT_CLASS (gnc_plugin_qif_import_parent_class)->finalize (object);
 }
 
 /************************************************************
@@ -112,8 +108,9 @@ gnc_plugin_qif_import_finalize (GObject *object)
  ************************************************************/
 
 static void
-gnc_plugin_qif_import_cmd_new_qif_import (GtkAction *action,
-        GncMainWindowActionData *data)
+gnc_plugin_qif_import_cmd_new_qif_import (GSimpleAction *simple,
+                                          GVariant      *parameter,
+                                          gpointer       user_data)
 {
     gnc_file_qif_import();
 }
