@@ -26,6 +26,10 @@
 #include "table-allgui.h"
 #include "gnucash-sheet.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /** @ingroup Register
  * @addtogroup Gnome
  * @{
@@ -87,4 +91,9 @@ void gnucash_register_set_open_doclink_cb (GnucashRegister *reg,
 GnucashSheet *gnucash_register_get_sheet (GnucashRegister *reg);
 void gnucash_register_reset_sheet_layout (GnucashRegister *reg);
 /** @} */
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
