@@ -44,6 +44,7 @@ struct _GnucashSheet
     gpointer popup_data;
 
     Table *table;
+    gboolean read_only;
 
     GtkWidget *reg;
 
@@ -88,7 +89,6 @@ struct _GnucashSheet
 
     guint insert_signal;
     guint delete_signal;
-    guint changed_signal;
 
     GtkAdjustment *hadj, *vadj;
     GtkWidget *hscrollbar, *vscrollbar;
@@ -96,25 +96,13 @@ struct _GnucashSheet
     GFunc moved_cb;
     gpointer moved_cb_data;
 
-    /* IMContext */
-    GtkIMContext *im_context;
-    gint preedit_length; /** num of bytes */
-    gint preedit_char_length; /** num of chars in UTF-8 */
-    gint preedit_start_position; /** save preedit start position   *
-                                      * combined with selection start */
-    gint preedit_cursor_position; /** save preedit cursor position */
-    gint preedit_selection_length;
-    PangoAttrList *preedit_attrs;
-    gboolean need_im_reset;
-    gboolean direct_update_cell;
-    guint commit_signal;
-    guint preedit_changed_signal;
-    guint retrieve_surrounding_signal;
-    guint delete_surrounding_signal;
+    GFunc open_doclink_cb;
+    gpointer open_doclink_cb_data;
 
     guint shift_state;
     guint keyval_state;
-    int start_sel, end_sel;
+    gboolean direct_update_cell; /** Indicates that this cell has special operation keys. */
+    int pos, bound; /** Corresponds to GtkEditable's current_pos and selection_bound */
 
 };
 
@@ -129,9 +117,6 @@ GncItemEdit *gnucash_sheet_get_item_edit (GnucashSheet *sheet);
 void gnucash_sheet_set_popup (GnucashSheet *sheet, GtkWidget *popup, gpointer data);
 void gnucash_sheet_goto_virt_loc (GnucashSheet *sheet, VirtualLocation virt_loc);
 void gnucash_sheet_refresh_from_prefs (GnucashSheet *sheet);
-//Table       *gnucash_sheet_get_table (GnucashSheet *sheet);
-//gint         gnucash_sheet_get_num_virt_rows (GnucashSheet *sheet);
-//gint         gnucash_sheet_get_num_virt_cols (GnucashSheet *sheet);
 
 gboolean   gnucash_sheet_find_loc_by_pixel (GnucashSheet *sheet, gint x, gint y,
                                            VirtualLocation *vcell_loc);
@@ -139,7 +124,5 @@ gboolean gnucash_sheet_draw_internal (GnucashSheet *sheet, cairo_t *cr,
                                       GtkAllocation *alloc);
 void gnucash_sheet_draw_cursor (GnucashCursor *cursor, cairo_t *cr);
 
-void gnc_widget_set_css_name (GtkWidget *widget, const char *name);
-
 /** @} */
 #endif
