@@ -56,12 +56,10 @@ style_get_key (SheetBlockStyle *style)
 static gpointer
 style_create_key (SheetBlockStyle *style)
 {
-    static gint key;
-    gpointer new_key;
+    gint key = style->cursor->num_rows;
 
-    key = style->cursor->num_rows;
-    new_key = g_malloc(sizeof(key));
-    new_key = memcpy(new_key, &key, sizeof(key));
+    gint *new_key = g_new(gint, 1);
+    *new_key = key;
 
     return new_key;
 }
@@ -279,7 +277,7 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
 
     width = 0;
     num_cols = cursor->num_cols;
-    widths = g_new (int, num_cols);
+    widths = g_new0 (int, num_cols);
 
     /* find header widths */
     for (col = 0; col < num_cols; col++)
@@ -320,7 +318,6 @@ set_dimensions_pass_two (GnucashSheet *sheet, int default_width)
             BasicCell *cell;
             const char *text;
             int sample_width;
-            int old_width;
             PangoLayout *layout;
 
             cell = gnc_cellblock_get_cell (cursor, 0, col);
