@@ -42,6 +42,7 @@
 #include <gnc-guile-utils.h>
 #include <gnc-engine.h>
 #include "gnc-report.h"
+#include <charconv>
 
 extern "C" SCM scm_init_sw_report_module(void);
 
@@ -257,12 +258,32 @@ gnc_report_name( SCM report )
     return gnc_scm_call_1_to_string(get_name, report);
 }
 
+gint
+gnc_report_id_string_to_report_id (const char *id_string)
+{
+    g_return_val_if_fail (id_string, -1);
+
+    const char *end_ptr = id_string + std::strlen (id_string);
+    gint rpt_id;
+    auto res = std::from_chars (id_string, end_ptr, rpt_id);
+    if (res.ec != std::errc() || rpt_id < 0) return -1;
+    if (res.ptr == end_ptr) return rpt_id;
+    if (*res.ptr != '|') return -1;
+
+    gint anchor_id;
+    res = std::from_chars (res.ptr + 1, end_ptr, anchor_id);
+    if (res.ec != std::errc() || *res.ptr != '\0' || anchor_id < 0) return -1;
+
+    const SCM get_linked = scm_c_eval_string ("gnc:report-get-linked-report");
+
+    auto id = scm_call_2 (get_linked, scm_from_int (rpt_id), scm_from_int (anchor_id));
+    return scm_is_number (id) ? scm_to_int (id) : -1;
+}
+
 gboolean
 gnc_run_report_id_string_with_error_handling (const char * id_string, char **data,
                                               gchar **errmsg)
 {
-    gint report_id;
-
     g_return_val_if_fail (id_string, FALSE);
     g_return_val_if_fail (data, FALSE);
     *data = NULL;
@@ -270,7 +291,8 @@ gnc_run_report_id_string_with_error_handling (const char * id_string, char **dat
     if (strncmp ("id=", id_string, 3) != 0)
         return FALSE;
 
-    if (sscanf (id_string + 3, "%d", &report_id) != 1)
+    gint report_id = gnc_report_id_string_to_report_id (id_string + 3);
+    if (report_id < 0)
         return FALSE;
 
     return gnc_run_report_with_error_handling (report_id, data, errmsg);
