@@ -35,12 +35,6 @@ gfec_string_from_locale(void *data)
     return scm_from_locale_string(str);
 }
 
-static SCM
-gfec_string_outer_handler(void *data, SCM key, SCM args)
-{
-    return SCM_UNDEFINED;
-}
-
 static SCM
 gfec_string_inner_handler(void *data, SCM key, SCM args)
 {
