@@ -38,8 +38,10 @@ gnc_default_currency(void)
     return gnc_commodity_table_lookup(table, GNC_COMMODITY_NS_CURRENCY, "USD");
 }
 }
-
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcpp"
 #include <gtest/gtest.h>
+#pragma GCC diagnostic pop
 #include "../gnc-quotes.cpp"
 
 class GncMockQuoteSource final : public GncQuoteSource
@@ -181,17 +183,19 @@ TEST_F(GncQuotesTest, offline_wiggle)
 {
     StrVec quote_vec{
         "{"
-        "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004},"
+         "\"currency\":{"
+        "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004}},"
+        "\"alphavantage\":{"
         "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Alphavantage\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"alphavantage\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
         "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"alphavantage\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Alphavantage\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1},"
         "\"FKCM\":{\"success\":0,\"symbol\":\"FKCM\",\"errormsg\":\"Error retrieving quote for FKCM - no listing for this name found. Please check symbol and the two letter extension (if any)\"}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     GncQuotesImpl quotes(m_book, std::make_unique<GncMockQuoteSource>(std::move(quote_vec), std::move(err_vec)));
     quotes.fetch(m_book);
     auto failures{quotes.failures()};
-    ASSERT_EQ(1u, failures.size());
+    EXPECT_EQ(1u, failures.size());
     EXPECT_EQ(GncQuoteError::QUOTE_FAILED, std::get<2>(failures[0]));
     auto pricedb{gnc_pricedb_get_db(m_book)};
     EXPECT_EQ(3u, gnc_pricedb_get_num_prices(pricedb));
@@ -201,10 +205,11 @@ TEST_F(GncQuotesTest, offline_report)
 {
     StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Alphavantage\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"alphavantage\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
         "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"alphavantage\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Alphavantage\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1},"
         "\"FKCM\":{\"success\":0,\"symbol\":\"FKCM\",\"errormsg\":\"Error retrieving quote for FKCM - no listing for this name found. Please check symbol and the two letter extension (if any)\"}"
-        "}"
+        "}}"
     };
     StrVec commodities{"AAPL", "HPE", "FKCM"};
     StrVec err_vec;
@@ -217,8 +222,9 @@ TEST_F(GncQuotesTest, offline_currency_report)
 {
     StrVec quote_vec{
         "{"
+         "\"currency\":{"
         "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004}"
-        "}"
+        "}}"
     };
     StrVec commodities{"USD", "EUR"};
     StrVec err_vec;
@@ -231,9 +237,10 @@ TEST_F(GncQuotesTest, comvec_fetch)
 {
      StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Alphavantage\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"alphavantage\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
         "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"alphavantage\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Alphavantage\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -252,8 +259,9 @@ TEST_F(GncQuotesTest, fetch_one_commodity)
 {
      StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"currency\":\"USD\",\"success\":1}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -281,8 +289,9 @@ TEST_F(GncQuotesTest, fetch_one_currency)
 {
      StrVec quote_vec{
          "{"
+         "\"currency\":{"
          "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004}"
-         "}"
+         "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -312,8 +321,9 @@ TEST_F(GncQuotesTest, no_currency)
 {
      StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"success\":1}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -331,8 +341,9 @@ TEST_F(GncQuotesTest, bad_currency)
 {
      StrVec quote_vec{
         "{"
-        "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"currency\":\"BTC\",\"success\":1}"
-        "}"
+       "\"alphavantage\":{"
+         "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"currency\":\"BTC\",\"success\":1}"
+        "}}"
      };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -350,8 +361,9 @@ TEST_F(GncQuotesTest, no_date)
 {
      StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"HPE\":{\"last\":13.37,\"currency\":\"USD\",\"success\":1}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -366,7 +378,7 @@ TEST_F(GncQuotesTest, no_date)
     auto datetime{static_cast<time64>(GncDateTime())};
 
     EXPECT_EQ(usd, gnc_price_get_currency(price));
-    EXPECT_EQ(datetime, gnc_price_get_time64(price));
+    EXPECT_TRUE (abs(datetime - gnc_price_get_time64(price)) <= 1);
     EXPECT_EQ(PRICE_SOURCE_FQ, gnc_price_get_source(price));
     EXPECT_TRUE(gnc_numeric_equal(GncNumeric{1337, 100},
                                   gnc_price_get_value(price)));
