@@ -26,8 +26,6 @@
 
 #include <kvp-frame.hpp>
 
-extern "C"
-{
 #include <config.h>
 
 #include <sys/types.h>
@@ -50,15 +48,11 @@ extern "C"
 #include "gncInvoice.h"
     /* For version_control */
 #include <gnc-prefs.h>
-}
 /* For test_conn_index_functions */
 #include "../gnc-backend-dbi.hpp"
 #include "../gnc-backend-dbi.h"
-extern "C"
-{
 #include <unittest-support.h>
 #include <test-stuff.h>
-}
 
 #include <string>
 #include <vector>
@@ -77,6 +71,9 @@ static dbi_inst dbi_instance = NULL;
 static const gchar* suitename = "/backend/dbi";
 void test_suite_gnc_backend_dbi (void);
 
+static std::string mysql_url{};
+static std::string pgsql_url{};
+
 using StrVec = std::vector<std::string>;
 
 typedef struct
@@ -86,6 +83,17 @@ typedef struct
     GSList* hdlrs;
 } Fixture;
 
+
+static char*
+normalize_path(char* path)
+{
+    g_return_val_if_fail(path, nullptr);
+    auto rv = gnc_uri_normalize_uri (path, FALSE);
+    g_free (path);
+    return rv;
+}
+
+
 static void
 setup (Fixture* fixture, gconstpointer pData)
 {
@@ -97,14 +105,17 @@ setup (Fixture* fixture, gconstpointer pData)
      * prevents creating the lock file. Force the session to get
      * around that.
      */
-    qof_session_begin (fixture->session, DBI_TEST_XML_FILENAME,
+    qof_session_begin (fixture->session,
+                       normalize_path (g_strdup (DBI_TEST_XML_FILENAME)),
                        SESSION_BREAK_LOCK);
     g_assert_cmpint (qof_session_get_error (fixture->session), == ,
                      ERR_BACKEND_NO_ERR);
     qof_session_load (fixture->session, NULL);
 
     if (g_strcmp0 (url, "sqlite3") == 0)
-        fixture->filename = g_strdup_printf ("/tmp/test-sqlite-%d", getpid ());
+        fixture->filename =
+            normalize_path (g_strdup_printf (TEMPDIR "/test-sqlite-%d",
+                                                    getpid ()));
     else
         fixture->filename = NULL;
 }
@@ -120,6 +131,7 @@ setup_memory (Fixture* fixture, gconstpointer pData)
     Split* spl1, *spl2;
     gnc_commodity_table* table;
     gnc_commodity* currency;
+    Time64 now{gnc_time(nullptr)};
 
     gnc_module_init_backend_dbi();
     root = gnc_book_get_root_account (book);
@@ -134,10 +146,10 @@ setup_memory (Fixture* fixture, gconstpointer pData)
     xaccAccountSetCommodity (acct1, currency);
 
     auto frame = qof_instance_get_slots (QOF_INSTANCE (acct1));
-    frame->set ({"int64-val"}, new KvpValue (INT64_C (100)));
+    frame->set ({"int64-val"}, new KvpValue (INT64_C (2148634028)));
     frame->set ({"double-val"}, new KvpValue (3.14159));
     frame->set ({"numeric-val"}, new KvpValue (gnc_numeric_zero ()));
-    frame->set ({"time-val"}, new KvpValue (gnc_time(nullptr)));
+    frame->set ({"time-val"}, new KvpValue (now));
     frame->set ({"string-val"}, new KvpValue (g_strdup ("abcdefghijklmnop")));
     auto guid = qof_instance_get_guid (QOF_INSTANCE (acct1));
     frame->set ({"guid-val"}, new KvpValue (const_cast<GncGUID*> (guid_copy (
@@ -160,7 +172,9 @@ setup_memory (Fixture* fixture, gconstpointer pData)
 
     fixture->session = session;
     if (g_strcmp0 (url, "sqlite3") == 0)
-        fixture->filename = g_strdup_printf ("/tmp/test-sqlite-%d", getpid ());
+        fixture->filename =
+            normalize_path (g_strdup_printf (TEMPDIR "/test-sqlite-%d",
+                                                    getpid ()));
     else
         fixture->filename = NULL;
 }
@@ -233,13 +247,15 @@ setup_business (Fixture* fixture, gconstpointer pData)
 
     emp = gncEmployeeCreate (book);
     gncEmployeeSetID (emp, "0001");
-    gncEmployeeSetUsername (emp, "gnucash");
+    gncEmployeeSetUsername (emp, PROJECT_NAME);
     gncEmployeeSetLanguage (emp, "english");
     gncEmployeeSetCurrency (emp, currency);
 
     fixture->session = session;
     if (g_strcmp0 (url, "sqlite3") == 0)
-        fixture->filename = g_strdup_printf ("/tmp/test-sqlite-%d", getpid ());
+        fixture->filename =
+            normalize_path (g_strdup_printf (TEMPDIR "/test-sqlite-%d",
+                                                    getpid ()));
     else
         fixture->filename = NULL;
 }
@@ -252,12 +268,10 @@ destroy_database (gchar* url)
     gchar* dbname = NULL;
     gchar* username = NULL;
     gchar* password = NULL;
-    gchar* basename = NULL;
     gint portnum = 0;
     gchar* port = NULL;
     auto pgsql = "pgsql";
     dbi_conn conn = NULL;
-    auto errfmt = "Unable to delete tables in %s: %s";
     gint fail = 0;
     dbi_result tables;
     StrVec tblnames;
@@ -279,7 +293,7 @@ destroy_database (gchar* url)
     port = g_strdup_printf ("%d", portnum);
     if (conn == NULL)
     {
-        g_printf (errfmt, url, "failed to create connection");
+        g_printf ("delete tables in %s: failed to create connection", url);
         return;
     }
     fail = dbi_conn_set_option (conn, "host", host);
@@ -296,7 +310,7 @@ destroy_database (gchar* url)
     g_free (port);
     if (fail != 0)
     {
-        g_printf (errfmt, url, "failed to set an option");
+        g_printf ("delete tables in %s: failed to set an option", url);
         dbi_conn_close (conn);
         return;
     }
@@ -305,7 +319,7 @@ destroy_database (gchar* url)
     {
         const gchar* error;
         gint errnum = dbi_conn_error (conn, &error);
-        g_printf (errfmt, url, error);
+        g_printf ("delete tables in %s: failed to connect (error %d): %s", url, errnum, error);
         dbi_conn_close (conn);
         return;
     }
@@ -321,6 +335,7 @@ destroy_database (gchar* url)
                      std::string query{"DROP TABLE "};
                      query += table;
                      dbi_result rslt = dbi_conn_query (conn, query.c_str());
+                     dbi_result_free(rslt);
                   });
 }
 
@@ -368,7 +383,7 @@ test_conn_index_functions (QofBackend* qof_be)
     {
         const char* errmsg;
         conn->provider()->drop_index (dbi_be->conn, index);
-        g_assert (DBI_ERROR_NONE == dbi_conn_error (conn->conn(), &errmsg));
+        g_assert_true (DBI_ERROR_NONE == dbi_conn_error (conn->conn(), &errmsg));
     }
 
 }
@@ -395,23 +410,23 @@ test_dbi_store_and_reload (Fixture* fixture, gconstpointer pData)
     auto book2{qof_book_new()};
     auto session_2 = qof_session_new (book2);
     qof_session_begin (session_2, url, SESSION_NEW_OVERWRITE);
-    g_assert (session_2 != NULL);
+    g_assert_true (session_2 != NULL);
     g_assert_cmpint (qof_session_get_error (session_2), == , ERR_BACKEND_NO_ERR);
     qof_session_swap_data (fixture->session, session_2);
     qof_book_mark_session_dirty (qof_session_get_book (session_2));
     qof_session_save (session_2, NULL);
-    g_assert (session_2 != NULL);
+    g_assert_true (session_2 != NULL);
     g_assert_cmpint (qof_session_get_error (session_2), == , ERR_BACKEND_NO_ERR);
 
     // Reload the session data
     auto book3{qof_book_new()};
     auto session_3 = qof_session_new (book3);
-    g_assert (session_3 != NULL);
+    g_assert_true (session_3 != NULL);
     qof_session_begin (session_3, url, SESSION_READ_ONLY);
-    g_assert (session_3 != NULL);
+    g_assert_true (session_3 != NULL);
     g_assert_cmpint (qof_session_get_error (session_3), == , ERR_BACKEND_NO_ERR);
     qof_session_load (session_3, NULL);
-    g_assert (session_3 != NULL);
+    g_assert_true (session_3 != NULL);
     g_assert_cmpint (qof_session_get_error (session_3), == , ERR_BACKEND_NO_ERR);
     // Compare with the original data
     compare_books (qof_session_get_book (session_2),
@@ -454,7 +469,7 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %d, %s", qof_session_get_error (session_1),
                    qof_session_get_error_message (session_1));
         g_test_message ("DB Session Creation Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     qof_session_swap_data (fixture->session, session_1);
@@ -467,7 +482,7 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %s",
                    qof_session_get_error_message (session_1));
         g_test_message ("DB Session Safe Save Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     /* Destroy the session and reload it */
@@ -480,7 +495,7 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %d, %s", qof_session_get_error (session_2),
                    qof_session_get_error_message (session_2));
         g_test_message ("DB Session re-creation Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     qof_session_load (session_2, NULL);
@@ -527,7 +542,7 @@ test_dbi_version_control (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %d, %s", qof_session_get_error (sess),
                    qof_session_get_error_message (sess));
         g_test_message ("DB Session Creation Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     qof_session_swap_data (fixture->session, sess);
@@ -649,7 +664,7 @@ create_dbi_test_suite (const char* dbm_name, const char* url)
     GNC_TEST_ADD (subsuite, "version_control", Fixture, url, setup_memory,
                   test_dbi_version_control, teardown);
     GNC_TEST_ADD (subsuite, "business_store_and_reload", Fixture, url,
-                  setup_business, test_dbi_version_control, teardown);
+                  setup_business, test_dbi_business_store_and_reload, teardown);
     g_free (subsuite);
 
 }
@@ -670,19 +685,24 @@ test_suite_gnc_backend_dbi (void)
     {
         drivers.push_back(dbi_driver_get_name (driver));
     }
+    mysql_url.append(getenv("TEST_MYSQL_URL") ? getenv("TEST_MYSQL_URL") : "");
+    pgsql_url.append(getenv("TEST_PGSQL_URL") ? getenv("TEST_PGSQL_URL") : "");
+
+    sort(drivers.begin(), drivers.end());
+
     for (auto name : drivers)
     {
         if (name == "sqlite3")
             create_dbi_test_suite ("sqlite3", "sqlite3");
-        if (strlen (TEST_MYSQL_URL) > 0 && name == "mysql")
-            create_dbi_test_suite ("mysql", TEST_MYSQL_URL);
-        if (strlen (TEST_PGSQL_URL) > 0 && name == "pgsql")
+        if (!mysql_url.empty() && name == "mysql")
+            create_dbi_test_suite ("mysql", mysql_url.c_str());
+        if (!pgsql_url.empty() && name == "pgsql")
         {
             g_setenv ("PGOPTIONS", "-c client_min_messages=WARNING", FALSE);
-            create_dbi_test_suite ("postgres", TEST_PGSQL_URL);
+            create_dbi_test_suite ("postgres", pgsql_url.c_str());
         }
     }
 
-    GNC_TEST_ADD_FUNC( suitename, "adjust sql options string localtime", 
+    GNC_TEST_ADD_FUNC( suitename, "adjust sql options string localtime",
         test_adjust_sql_options_string );
 }
