@@ -375,7 +375,7 @@ account_parent_handler (xmlNodePtr node, gpointer act_pdata)
     parent = xaccAccountLookup (gid, pdata->book);
     if (!parent)
     {
-        g_free (gid);
+        guid_free (gid);
         g_return_val_if_fail (parent, FALSE);
     }
 
