@@ -21,8 +21,6 @@
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
 \********************************************************************/
-extern "C"
-{
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
@@ -30,7 +28,6 @@ extern "C"
 #include "gncBillTermP.h"
 #include "gncInvoice.h"
 #include "qof.h"
-}
 
 #include "gnc-xml-helper.h"
 
@@ -154,11 +151,7 @@ static gboolean
 set_numeric (xmlNodePtr node, GncBillTerm* term,
              void (*func) (GncBillTerm*, gnc_numeric))
 {
-    gnc_numeric* num = dom_tree_to_gnc_numeric (node);
-    g_return_val_if_fail (num, FALSE);
-
-    func (term, *num);
-    g_free (num);
+    func (term, dom_tree_to_gnc_numeric (node));
     return TRUE;
 }
 
