@@ -23,8 +23,6 @@
  */
 #include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 
 #include <string.h>
@@ -33,7 +31,6 @@ extern "C"
 #include "cashobjects.h"
 #include "gnc-engine.h"
 #include "gnc-commodity.h"
-}
 
 #include <cstdlib>
 
@@ -166,7 +163,6 @@ static const char*
 test_gnc_nums_internal (gnc_numeric to_test)
 {
     const char* ret = NULL;
-    gnc_numeric* to_compare = NULL;
     xmlNodePtr to_gen = NULL;
 
     to_gen = gnc_numeric_to_dom_tree ("test-num", &to_test);
@@ -176,24 +172,13 @@ test_gnc_nums_internal (gnc_numeric to_test)
     }
     else
     {
-        to_compare = dom_tree_to_gnc_numeric (to_gen);
-        if (!to_compare)
+        gnc_numeric to_compare = dom_tree_to_gnc_numeric (to_gen);
+        if (!gnc_numeric_equal (to_test, to_compare))
         {
-            ret = "no gnc_numeric parsed";
-        }
-        else
-        {
-            if (!gnc_numeric_equal (to_test, *to_compare))
-            {
-                ret = "numerics compared different";
-            }
+            ret = "numerics compared different";
         }
     }
 
-    if (to_compare)
-    {
-        g_free (to_compare);
-    }
     if (to_gen)
     {
         xmlFreeNode (to_gen);
@@ -251,7 +236,7 @@ test_dom_tree_to_guid (void)
                  "dom_tree_to_guid");
 
         xmlFreeNode (test_node);
-        g_free (test_guid1);
+        guid_free (test_guid1);
         guid_free (test_guid2);
     }
 }
