@@ -79,6 +79,7 @@
 #define GNC_PREF_USE_GNUCASH_COLOR_THEME "use-gnucash-color-theme"
 #define GNC_PREF_TAB_TRANS_MEMORISED "tab-to-transfer-on-memorised"
 #define GNC_PREF_FUTURE_AFTER_BLANK  "future-after-blank-transaction"
+#define GNC_PREF_JUMP_MULT_SPLITS    "jump-multiple-splits"
 /* Date preferences */
 #define GNC_PREF_START_CHOICE_ABS    "start-choice-absolute"
 #define GNC_PREF_START_CHOICE_REL    "start-choice-relative"
@@ -254,15 +255,18 @@ void gnc_prefs_remove_group_cb_by_func (const gchar *group,
  *
  *  @param group This string contains the group name of the preference to bind to.
  *
- *  @param preference This string is the name of the particular preference to
+ *  @param pref_name This string is the name of the particular preference to
  *  bind to.
  *
+ *  @param pref_value This string is the enum value of the preference to bind to.
+ *
  *  @param object The object to be bound.
  *
  *  @param property The property of the object to bind to.
  */
 void gnc_prefs_bind (const gchar *group,
                      /*@ null @*/ const gchar *pref_name,
+                     /*@ null @*/ const gchar *pref_value,
                      gpointer object,
                      const gchar *property);
 
