@@ -115,6 +115,24 @@ test_g_list_stringjoin (gconstpointer data)
     g_list_free (test);
 }
 
+static void
+test_g_list_stringjoin_nodups (gconstpointer data)
+{
+    GList *test = NULL;
+    gchar *ret;
+
+    test = g_list_prepend (test, "one");
+    test = g_list_prepend (test, "two");
+    test = g_list_prepend (test, "two");
+    test = g_list_prepend (test, "three");
+    test = g_list_prepend (test, "one:two");
+    test = g_list_prepend (test, "four");
+    test = g_list_reverse (test);
+    ret = gnc_g_list_stringjoin_nodups (test, ":");
+    g_assert_cmpstr (ret, ==, "one:two:three:four");
+    g_free (ret);
+}
+
 static void
 test_gnc_list_length (gconstpointer data)
 {
@@ -146,6 +164,7 @@ main (int argc, char *argv[])
     g_test_add_data_func ("/core-utils/gnc_utf8_strip_invalid_and_controls invalid utf8", (gconstpointer)invalid_utf8, test_gnc_utf8_strip_invalid_and_controls);
     g_test_add_data_func ("/core-utils/gnc_utf8_strip_invalid_and_controls control chars", (gconstpointer)controls, test_gnc_utf8_strip_invalid_and_controls);
     g_test_add_data_func ("/core-utils/gnc_g_list_stringjoin", NULL, test_g_list_stringjoin);
+    g_test_add_data_func ("/core-utils/gnc_g_list_stringjoin_nodups", NULL, test_g_list_stringjoin_nodups);
     g_test_add_data_func ("/core-utils/gnc_list_length", NULL, test_gnc_list_length);
 
     return g_test_run();
