@@ -48,7 +48,7 @@ struct _gncBillTerm
     gint            cutoff;
 
     /* Internal management fields */
-    /* See src/doc/business.txt for an explanation of the following */
+    /* See libgnucash/engine/TaxTableBillTermImmutability.txt for an explanation of the following */
     /* Code that handles this is *identical* to that in gncTaxTable */
     gint64          refcount;
     GncBillTerm *   parent;      /* if non-null, we are an immutable child */
@@ -137,7 +137,7 @@ enum
 };
 
 /* GObject Initialization */
-G_DEFINE_TYPE(GncBillTerm, gnc_billterm, QOF_TYPE_INSTANCE);
+G_DEFINE_TYPE(GncBillTerm, gnc_billterm, QOF_TYPE_INSTANCE)
 
 static void
 gnc_billterm_init(GncBillTerm* bt)
@@ -839,14 +839,28 @@ static void _gncBillTermCreate (QofBook *book)
     qof_book_set_data (book, _GNC_MOD_NAME, bi);
 }
 
+
+static void
+destroy_billterm_on_book_close (QofInstance *ent, gpointer data)
+{
+    GncBillTerm *term = GNC_BILLTERM(ent);
+
+    gncBillTermBeginEdit (term);
+    gncBillTermDestroy (term);
+}
+
 static void _gncBillTermDestroy (QofBook *book)
 {
     struct _book_info *bi;
+    QofCollection *col;
 
     if (!book) return;
 
     bi = qof_book_get_data (book, _GNC_MOD_NAME);
 
+    col = qof_book_get_collection (book, GNC_ID_BILLTERM);
+    qof_collection_foreach (col, destroy_billterm_on_book_close, NULL);
+
     g_list_free (bi->terms);
     g_free (bi);
 }
