@@ -99,7 +99,7 @@ enum
 };
 
 /* GObject Initialization */
-G_DEFINE_TYPE(GncEmployee, gnc_employee, QOF_TYPE_INSTANCE);
+G_DEFINE_TYPE(GncEmployee, gnc_employee, QOF_TYPE_INSTANCE)
 
 static void
 gnc_employee_init(GncEmployee* emp)
