@@ -26,8 +26,6 @@
  */
 #include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 #include <ctype.h>
 #include "qof.h"
@@ -38,7 +36,6 @@ extern "C"
 #include "test-stuff.h"
 #include "test-engine-stuff.h"
 #include "Transaction.h"
-}
 
 static gint transaction_num = 32;
 static gint	max_iterate = 1;
@@ -82,7 +79,7 @@ test_lot_kvp ()
     g_assert_cmpstr (gnc_lot_get_notes (lot), ==, NULL);
 
     gnc_lot_destroy (lot);
-    qof_session_end (sess);
+    qof_session_destroy (sess);
 }
 
 static void
@@ -111,7 +108,7 @@ run_test (void)
      * XXX not implemented
      */
     success ("automatic lot scrubbing lightly tested and seem to work");
-    qof_session_end (sess);
+    qof_session_destroy (sess);
 
 }
 
