@@ -1149,11 +1149,6 @@ test_gnc_pricedb_lookup_day_t64 (PriceDBFixture *fixture, gconstpointer pData)
     g_log_set_default_handler (hdlr, 0);
 }
 
-// Not Used
-/* gnc_pricedb_lookup_at_time64
-GNCPrice *
-gnc_pricedb_lookup_at_time64(GNCPriceDB *db,// Local: 0:0:0
-*/
 /* lookup_nearest_in_time
 static GNCPrice *
 lookup_nearest_in_time(GNCPriceDB *db,// Local: 2:0:0
@@ -1592,11 +1587,6 @@ gnc_price_fixup_legacy_commods(gpointer data, gpointer user_data)// Local: 0:1:0
 test_gnc_price_fixup_legacy_commods (Fixture *fixture, gconstpointer pData)
 {
 }*/
-// Not Used
-/* gnc_pricedb_substitute_commodity
-void
-gnc_pricedb_substitute_commodity(GNCPriceDB *db,// Local: 0:0:0
-*/
 /* gnc_price_print
 void
 gnc_price_print(GNCPrice *p, FILE *f, int indent)// Local: 1:0:0
