@@ -35,41 +35,43 @@
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = G_LOG_DOMAIN;
 
-static void gnc_plugin_example_class_init         (GncPluginexampleClass *klass);
-static void gnc_plugin_example_init               (GncPluginexample *plugin);
 static void gnc_plugin_example_finalize           (GObject *object);
 
 /* Command callbacks */
-static void gnc_plugin_example_cmd_test (GtkAction *action, GncMainWindowActionData *data);
+static void gnc_plugin_example_cmd_test (GSimpleAction *simple, GVariant *parameter, gpointer user_data);
++{
 
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-example-actions"
-#define PLUGIN_UI_FILENAME  "gnc-plugin-example-ui.xml"
+#define PLUGIN_UI_FILENAME  "gnc-plugin-example.ui"
 
-static GtkActionEntry gnc_plugin_actions [] = {
-    /* Menu Items */
-    { "exampleAction", NULL, N_("example description..."), NULL,
-      N_("example tooltip"),
-      G_CALLBACK(gnc_plugin_example_cmd_test) },
+static GActionEntry gnc_plugin_actions [] =
+{
+    { "exampleAction", gnc_plugin_example_cmd_test, NULL, NULL, NULL },
 };
+/** The number of actions provided by this plugin. */
 static guint gnc_plugin_n_actions = G_N_ELEMENTS(gnc_plugin_actions);
 
-
 /************************************************************
  *                   Object Implementation                  *
  ************************************************************/
 
-G_DEFINE_TYPE(GncPluginexample, gnc_plugin_example, GNC_TYPE_PLUGIN)
+struct _GncPluginExample
+{
+    GncPlugin gnc_plugin;
+};
+
+G_DEFINE_TYPE(GncPluginExample, gnc_plugin_example, GNC_TYPE_PLUGIN)
 
 GncPlugin *
 gnc_plugin_example_new (void)
 {
-    return GNC_PLUGIN (g_object_new (GNC_TYPE_PLUGIN_example, (gchar*) NULL));
+    return GNC_PLUGIN (g_object_new (GNC_TYPE_PLUGIN_EXAMPLE, (gchar*) NULL));
 }
 
 static void
-gnc_plugin_example_class_init (GncPluginexampleClass *klass)
+gnc_plugin_example_class_init (GncPluginExampleClass *klass)
 {
-    GObjectClass *object_class = G_OBJECT_CLASS (klass);
+    GObjectClass *object_class = G_OBJECT_CLASS(klass);
     GncPluginClass *plugin_class = GNC_PLUGIN_CLASS(klass);
 
     object_class->finalize = gnc_plugin_example_finalize;
@@ -78,14 +80,14 @@ gnc_plugin_example_class_init (GncPluginexampleClass *klass)
     plugin_class->plugin_name  = GNC_PLUGIN_example_NAME;
 
     /* widget addition/removal */
-    plugin_class->actions_name       = PLUGIN_ACTIONS_NAME;
-    plugin_class->actions            = gnc_plugin_actions;
-    plugin_class->n_actions          = gnc_plugin_n_actions;
-    plugin_class->ui_filename        = PLUGIN_UI_FILENAME;
+    plugin_class->actions_name    = PLUGIN_ACTIONS_NAME;
+    plugin_class->actions         = gnc_plugin_actions;
+    plugin_class->n_actions       = gnc_plugin_n_actions;
+    plugin_class->ui_filename     = PLUGIN_UI_FILENAME;
 }
 
 static void
-gnc_plugin_example_init (GncPluginexample *plugin)
+gnc_plugin_example_init (GncPluginExample *plugin)
 {
 }
 
@@ -99,9 +101,12 @@ gnc_plugin_example_finalize (GObject *object)
  ************************************************************/
 
 static void
-gnc_plugin_example_cmd_test (GtkAction *action, GncMainWindowActionData *data)
+gnc_plugin_example_cmd_test (GSimpleAction *simple,
+                             GVariant      *parameter,
+                             gpointer       user_data)
 {
-    ENTER ("action %p, main window data %p", action, data);
-    PINFO ("example");
-    LEAVE (" ");
+    GncMainWindowActionData *data = user_data;
+    ENTER("action %p, main window data %p", simple, data);
+    PINFO("example");
+    LEAVE(" ");
 }
