@@ -107,8 +107,8 @@ gnc_module_system_search_dirs(void)
         case G_SEARCHPATH_SEPARATOR:
             if (!escchar)
             {
-                list = g_list_append(list, token->str);
-                g_string_free(token, FALSE);
+                char *token_str = g_string_free (token, FALSE);
+                list = g_list_append (list, token_str);
                 token = g_string_new(NULL);
             }
             else
@@ -126,8 +126,8 @@ gnc_module_system_search_dirs(void)
     }
     if (token->len)
     {
-        list = g_list_append(list, token->str);
-        g_string_free(token, FALSE);
+        char *token_str = g_string_free (token, FALSE);
+        list = g_list_append(list, token_str);
     }
     else
     {
@@ -228,9 +228,9 @@ gnc_module_system_refresh(void)
 
             /* Gotcha: On MacOS, G_MODULE_SUFFIX is defined as "so",
              * but if we do not build clean libtool modules with
-             * "-module", we get dynamic libraries ending on .dylib On
-             * Windows, all modules will move to bin/, so they will be
-             * mixed with other libraries, such as gtk+. Adding a
+             * "-module", we get dynamic libraries ending in .dylib
+             * On Windows, all modules will move to bin/, so they will
+             * be mixed with other libraries, such as gtk+. Adding a
              * prefix "libgncmod" filter will prevent the module loader
              * from loading other libraries. The filter should work on
              * other platforms.
